@@ -41,6 +41,7 @@
 #include "fitshistogram.h"
 #include "fitscommon.h"
 
+#include "skypoint.h"
 #include "dms.h"
 
 #define INITIAL_W	640
@@ -140,6 +141,7 @@ private:
     double stddev();
     int calculateMinMax(bool refresh=false);
     void checkWCS();
+    void readWCSKeys();
 
     bool markStars;
     float *image_buffer;				/* scaled image buffer (0-255) range */
