@@ -114,6 +114,9 @@ void INDI_P::initGUI ()
 
     QString label = i18nc(libindi_strings_context, dataProp->getLabel());
 
+    if (label == "(I18N_EMPTY_MESSAGE)")
+        label = dataProp->getLabel();
+
 
     /* add to GUI group */
     ledStatus = new KLed (pg->getContainer());
@@ -128,6 +131,9 @@ void INDI_P::initGUI ()
     if (label.isEmpty())
     {
         label = i18nc(libindi_strings_context, name.toUtf8());
+        if (label == "(I18N_EMPTY_MESSAGE)")
+            label =  name.toUtf8();
+
         labelW = new QLabel(label, pg->getContainer());
     }
     else
@@ -484,6 +490,7 @@ void INDI_P::sendText()
 void INDI_P::buildMenuGUI()
 {
     QStringList menuOptions;
+    QString oneOption;
     int onItem=-1;
     INDI_E *lp;
     ISwitchVectorProperty *svp = dataProp->getSwitch();
@@ -506,7 +513,12 @@ void INDI_P::buildMenuGUI()
 
         lp->buildMenuItem(tp);
 
-        menuOptions.append(i18nc(libindi_strings_context, lp->getLabel().toUtf8()));
+        oneOption = i18nc(libindi_strings_context, lp->getLabel().toUtf8());
+
+        if (oneOption == "(I18N_EMPTY_MESSAGE)")
+            oneOption =  lp->getLabel().toUtf8();
+
+        menuOptions.append(oneOption);
 
         elementList.append(lp);
     }
@@ -545,33 +557,15 @@ void INDI_P::addLayout(QHBoxLayout *layout)
         PVBox->addLayout(layout);
 }
 
-/*void INDI_P::processComboChange(const QString &item)
+void INDI_P::updateMenuGUI()
 {
-    int index=0;
     ISwitchVectorProperty *svp = dataProp->getSwitch();
-
     if (svp == NULL)
         return;
 
-    IURenewSwitch(svp);
-
-
-    foreach(INDI_E *el, elementList)
-    {
-        if (el->getLabel() == item)
-        {
-            svp->sp[index].s = ISS_ON;
-            svp->s = IPS_BUSY;
-
-            pg->getDevice()->getClientManager()->sendNewswitch(tvp, &(tvp->sp[index]));
-        }
-
-        el->updateswitchState();
-        index++;
-    }
-
-    updateStateLED();
-}*/
+    int currentIndex = IUFindOnSwitchIndex(svp);
+    menuC->setCurrentIndex(currentIndex);
+}
 
 void INDI_P::processSetButton()
 {
@@ -645,10 +639,11 @@ void INDI_P::sendBlob()
 void INDI_P::newTime()
 {
     INDI_E * timeEle;
-    //INDI_P *SDProp;
+    INDI_E * offsetEle;
 
-    timeEle = getElement("UTC");
-    if (!timeEle) return;
+    timeEle   = getElement("UTC");
+    offsetEle = getElement("OFFSET");
+    if (!timeEle || !offsetEle) return;
 
     TimeDialog timedialog ( KStars::Instance()->data()->ut(), KStars::Instance()->data()->geo(), KStars::Instance(), true );
 
@@ -662,17 +657,13 @@ void INDI_P::newTime()
                          .arg(newDate.day()).arg(newTime.hour())
                          .arg(newTime.minute()).arg(newTime.second()));
 
+        offsetEle->setText(QString().setNum(KStars::Instance()->data()->geo()->TZ(), 'g', 2));
+
         sendText();
+
     }
     else return;
 
-    /*SDProp  = pp->pg->dp->findProp("TIME_LST");
-    if (!SDProp) return;
-    timeEle = SDProp->findElement("LST");
-    if (!timeEle) return;
-
-    timeEle->write_w->setText(ksw->data()->lst()->toHMSString());
-    SDProp->newText();*/
 }
 
 INDI_E * INDI_P::getElement(const QString &elementName)
